@@ -35,7 +35,8 @@ def patch_path(dir_path):
 
 def patch_config(config_path, line):
     if not os.path.isfile(config_path):
-        return
+        with open(config_path, "w", encoding="utf8") as f:
+            f.write("")
     with open(config_path, "r", encoding="utf8") as f:
         cnt = f.read()
     lines = cnt.split("\n")
